==> gnome-commander_0.9.6.orig.tar.gz: gnome-commander-0.9.6/src/gnome-cmd-main-win-funcs.h <==
/*
    GNOME Commander - A GNOME based file manager 
    Copyright (C) 2001-2002 Marcus Bjurman

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/ 
#ifndef __GNOME_CMD_MAIN_WIN_FUNCS_H__
#define __GNOME_CMD_MAIN_WIN_FUNCS_H__

GtkType
gnome_cmd_main_win_get_type              (void);

GtkWidget*
gnome_cmd_main_win_new                   (void);

GnomeCmdFileSelector*
gnome_cmd_main_win_get_active_fs         (GnomeCmdMainWin *mw);

GnomeCmdFileSelector*
gnome_cmd_main_win_get_inactive_fs       (GnomeCmdMainWin *mw);

GnomeCmdFileSelector*
gnome_cmd_main_win_get_left_fs           (GnomeCmdMainWin *mw);

GnomeCmdFileSelector*
gnome_cmd_main_win_get_right_fs          (GnomeCmdMainWin *mw);

void
gnome_cmd_main_win_update_style          (GnomeCmdMainWin *mw);

void
gnome_cmd_main_win_hide_embterm          (GnomeCmdMainWin *mw);

void
gnome_cmd_main_win_show_embterm          (GnomeCmdMainWin *mw);

#endif //__GNOME_CMD_MAIN_WIN_FUNCS_H__

==> gnome-commander_1.0.1.orig.tar.gz: gnome-commander-1.0.1/src/gnome-cmd-main-win-funcs.h <==
/*
    GNOME Commander - A GNOME based file manager 
    Copyright (C) 2001-2003 Marcus Bjurman

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/ 
#ifndef __GNOME_CMD_MAIN_WIN_FUNCS_H__
#define __GNOME_CMD_MAIN_WIN_FUNCS_H__

#include "gnome-cmd-main-win-types.h"
#include "gnome-cmd-file-selector-types.h"
#include "gnome-cmd-cmdline.h"

GtkType
gnome_cmd_main_win_get_type              (void);

GtkWidget*
gnome_cmd_main_win_new                   (void);

GnomeCmdFileSelector*
gnome_cmd_main_win_get_active_fs         (GnomeCmdMainWin *mw);

GnomeCmdFileSelector*
gnome_cmd_main_win_get_inactive_fs       (GnomeCmdMainWin *mw);

GnomeCmdFileSelector*
gnome_cmd_main_win_get_left_fs           (GnomeCmdMainWin *mw);

GnomeCmdFileSelector*
gnome_cmd_main_win_get_right_fs          (GnomeCmdMainWin *mw);

GnomeCmdCmdline*
gnome_cmd_main_win_get_cmdline           (GnomeCmdMainWin *mw);

void
gnome_cmd_main_win_update_style          (GnomeCmdMainWin *mw);

void
gnome_cmd_main_win_hide_embterm          (GnomeCmdMainWin *mw);

void
gnome_cmd_main_win_show_embterm          (GnomeCmdMainWin *mw);

void
gnome_cmd_main_win_new_cwd               (GnomeCmdMainWin *mw,
										  const gchar *cwd);

void
gnome_cmd_main_win_focus_cmdline         (GnomeCmdMainWin *mw);

void
gnome_cmd_main_win_focus_file_lists      (GnomeCmdMainWin *mw);

gboolean
gnome_cmd_main_win_keypressed            (GnomeCmdMainWin *mw,
										  GdkEventKey *event);
void
gnome_cmd_main_win_switch_fs             (GnomeCmdMainWin *mw,
										  GnomeCmdFileSelector *fs);

void
gnome_cmd_main_win_update_bookmarks      (GnomeCmdMainWin *mw);

void
gnome_cmd_main_win_set_toolbar_visibility (GnomeCmdMainWin *mw,
										   gboolean value);

void
gnome_cmd_main_win_set_buttonbar_visibility (GnomeCmdMainWin *mw,
											 gboolean value);

#endif //__GNOME_CMD_MAIN_WIN_FUNCS_H__
